@@ -32,6 +32,7 @@
 
 #include <QSystemInfo>
 #include <QTcpSocket>
+#include <QTimer>
 #include <QObject>
 #include <QString>
 #include <QStringList>
@@ -231,10 +232,16 @@ public slots:
     // Sends a no operation (ping) to the network
     void sendNop();
 
+    // Sends a ping request to th3e network
+    void sendPing();
+
     // Changes the user name or alias
     void setNewUserName(QString push_name);
 
 
+    // Connection timeout handling
+    void connectionTimeout();
+
 private:
 
     /** ***********************************************************************
@@ -289,6 +296,9 @@ private:
     // Reader crypto stream
     KeyStream *inputKey;
 
+    // Connection timeout timer
+    QTimer connTimeout;
+
 
     /** ***********************************************************************
      ** Private methods
@@ -488,7 +498,8 @@ signals:
      ** General signals
      **/
 
-    void connectionClosed();
+    // Connection timeout
+    void timeout();
 };
 
 
